@@ -8,38 +8,6 @@ pub struct Coord {
     pub y: i32,
 }
 
-/// ## creating a new Coord
-/// #### Example
-/// ```rust
-/// use coord2d::*;
-///
-/// let a: coords::Coord = new_coord!(1, 2.0);
-/// println!("{:?}", a);
-/// // returns Coord {x: 1.0, y: 2.0}
-/// let a: coords::Coord = new_coord!(2.0);
-/// println!("{:?}", a);
-/// // returns Coord {x: 0.0, y: 2.0}
-/// ```
-/// * the var **a** contains to var x and y as position in a graph (O, I, J)
-/// * returns i32
-#[macro_export]
-macro_rules! new_coord {
-    () => {
-        $crate::coords::Coord { x: 0, y: 0 }
-    };
-
-    ($y:expr) => {
-        $crate::coords::Coord { x: 0, y: $y as i32 }
-    };
-
-    ($x:expr, $y:expr) => {
-        $crate::coords::Coord {
-            x: $x as i32,
-            y: $y as i32,
-        }
-    };
-}
-
 /// ## implementations
 impl Coord {
     /// ### converting to a Vec
